Module expr

Module expr 

Modules

constant
Nested message and enum types in Constant.
decl
Nested message and enum types in Decl.
expr
Nested message and enum types in Expr.
source_info
Nested message and enum types in SourceInfo.
type
Nested message and enum types in Type.

Structs

CheckedExpr
A CEL expression which has been successfully type checked.
Constant
Represents a primitive literal.
Decl
Represents a declaration of a named value or function.
Expr
An abstract representation of a common expression.
ParsedExpr
An expression together with source information as returned by the parser.
Reference
Describes a resolved reference to a declaration.
SourceInfo
Source information collected at parse time.
Type
Represents a CEL type.