pub trait CheckRequestExt: Sealed {
// Required methods
fn get_client_address(&self) -> Option<&String>;
fn get_client_headers(&self) -> Option<&HashMap<String, String>>;
}Expand description
Extension trait aiming to provide convenient methods to get useful
data from pb::CheckRequest.
This trait is sealed and not meant to be implemented outside of
envoy-types.
Required Methods
Sourcefn get_client_address(&self) -> Option<&String>
fn get_client_address(&self) -> Option<&String>
Returns a reference to the pb::CheckRequest’s source peer
pb::Address::SocketAddress inner value, if any.
In cases where Envoy is acting as an Edge Proxy, this should match the client’s IP.